#ifndef NT2_INCLUDE_FUNCTIONS_CEIL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CEIL_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/ceil.hpp>

#endif
